html, body {
  height: 100%;
  background-color: #eee;
}
.cover-container {
  max-width: 50em;
}

/* Page title */
#app-name {
  color: #000;
  text-shadow: 0 .05rem .2rem rgba(255, 255, 255, .5);
}
#app-name img {
  width: 110px;
  margin-right: 1rem;
}
@media screen and (max-width: 680px) {
  #app-name img {
      display: block;
      margin: auto;
  }
}

/* Add icons to login form */
/* Font-Awesome attribution is already done inside SVG files */
.form-signin input[type="text"] {
  background: right 1rem top 50% / 5% no-repeat url('fa-user.svg');
  padding-right: 3rem;
}
.form-signin input[type="password"] {
  background: right 1rem top 50% / 5% no-repeat url('fa-lock.svg');
  padding-right: 3rem;
}
